# pytheriak
Python wrapper functions for Theriak-Domino

## Installation

Run the following to install:

```python
pip install pytheriak
```

## Usage

Example how to setup a link, call and read from theriak with pytheriak.
```python
TherCaller()
```
